@@ -170,8 +170,7 @@ class Ppos(Module):
         try:
             for i in raw_data:
                 i["Shares"] = int(i["Shares"], 16)
-        except:
-            pass
+        except:...
         return parse
 
     def getValidatorList(self, from_address=None):
@@ -188,8 +187,7 @@ class Ppos(Module):
         try:
             for i in raw_data:
                 i["Shares"] = int(i["Shares"], 16)
-        except:
-            pass
+        except:...
         return parse
 
     def getCandidateList(self, from_address=None):
@@ -210,8 +208,7 @@ class Ppos(Module):
                 i["ReleasedHes"] = int(i["ReleasedHes"], 16)
                 i["RestrictingPlan"] = int(i["RestrictingPlan"], 16)
                 i["RestrictingPlanHes"] = int(i["RestrictingPlanHes"], 16)
-        except:
-            pass
+        except:...
         return parse
 
     def getRelatedListByDelAddr(self, del_addr, from_address=None):
@@ -245,15 +242,13 @@ class Ppos(Module):
         receive = json.loads(str(raw_data, encoding="utf8"))
         raw_data_dict = receive["Ret"]
         try:
-            data = json.loads(raw_data_dict)
-            data["Released"] = int(data["Released"], 16)
-            data["ReleasedHes"] = int(data["ReleasedHes"], 16)
-            data["RestrictingPlan"] = int(data["RestrictingPlan"], 16)
-            data["RestrictingPlanHes"] = int(data["RestrictingPlanHes"], 16)
-            data["Reduction"] = int(data["Reduction"], 16)
-            receive["Ret"] = data
-        except:
-            pass
+            raw_data_dict["Released"] = int(raw_data_dict["Released"], 16)
+            raw_data_dict["ReleasedHes"] = int(raw_data_dict["ReleasedHes"], 16)
+            raw_data_dict["RestrictingPlan"] = int(raw_data_dict["RestrictingPlan"], 16)
+            raw_data_dict["RestrictingPlanHes"] = int(raw_data_dict["RestrictingPlanHes"], 16)
+            raw_data_dict["Reduction"] = int(raw_data_dict["Reduction"], 16)
+            receive["Ret"] = raw_data_dict
+        except:...
         return receive
 
     def getCandidateInfo(self, node_id, from_address=None):
@@ -276,8 +271,7 @@ class Ppos(Module):
             raw_data_dict["RestrictingPlan"] = int(raw_data_dict["RestrictingPlan"], 16)
             raw_data_dict["RestrictingPlanHes"] = int(raw_data_dict["RestrictingPlanHes"], 16)
             receive["Ret"] = raw_data_dict
-        except:
-            pass
+        except:...
         return receive
 
     def reportDuplicateSign(self, typ, data, pri_key, transaction_cfg=None):
@@ -369,14 +363,12 @@ class Ppos(Module):
         receive = json.loads(str(raw_data, encoding="ISO-8859-1"))
         raw_data_dict = receive["Ret"]
         try:
-            data = json.loads(raw_data_dict)
-            data["balance"] = int(data["balance"], 16)
-            data["Pledge"] = int(data["Pledge"], 16)
-            data["debt"] = int(data["debt"], 16)
-            if data["plans"]:
-                for i in data["plans"]:
+            raw_data_dict["balance"] = int(raw_data_dict["balance"], 16)
+            raw_data_dict["Pledge"] = int(raw_data_dict["Pledge"], 16)
+            raw_data_dict["debt"] = int(raw_data_dict["debt"], 16)
+            if raw_data_dict["plans"]:
+                for i in raw_data_dict["plans"]:
                     i["amount"] = int(i["amount"], 16)
-            receive["Ret"] = data
-        except:
-            pass
+            receive["Ret"] = raw_data_dict
+        except:...
         return receive
